@@ -62,7 +62,7 @@ impl ChainRPC {
     }
 
     pub fn gaia(q: &str) -> ChainRPC {
-        let endpoint = "https://rpc.cosmos.network:443/";
+        let endpoint = "https://cosmoshub.validator.network/";
         ChainRPC::launch_from_endpoint(endpoint, q)
     }
 
